@@ -20,14 +20,10 @@
 #ifndef XFCE4_CPUFREQ_LINUX_PROCFS_H
 #define XFCE4_CPUFREQ_LINUX_PROCFS_H
 
-G_BEGIN_DECLS
+bool cpufreq_procfs_is_available ();
 
-gboolean cpufreq_procfs_is_available (void);
+bool cpufreq_procfs_read ();
 
-gboolean cpufreq_procfs_read (void);
-
-gboolean cpufreq_procfs_read_cpuinfo (void);
-
-G_END_DECLS
+bool cpufreq_procfs_read_cpuinfo ();
 
 #endif /* XFCE4_CPUFREQ_LINUX_PROCFS_H */
