@@ -20,12 +20,8 @@
 #ifndef XFCE4_CPUFREQ_LINUX_PSTATE_H
 #define XFCE4_CPUFREQ_LINUX_PSTATE_H
 
-G_BEGIN_DECLS
+bool cpufreq_pstate_is_available ();
 
-gboolean cpufreq_pstate_is_available (void);
-
-gboolean cpufreq_pstate_read (void);
-
-G_END_DECLS
+bool cpufreq_pstate_read ();
 
 #endif /* XFCE4_CPUFREQ_LINUX_PSTATE_H */
