@@ -21,14 +21,12 @@
 #ifndef XFCE4_CPUFREQ_LINUX_H
 #define XFCE4_CPUFREQ_LINUX_H
 
-G_BEGIN_DECLS
+#include <glib.h>
 
-gboolean
-cpufreq_update_cpus (gpointer data);
+void
+cpufreq_update_cpus ();
 
-gboolean
-cpufreq_linux_init (void);
-
-G_END_DECLS
+bool
+cpufreq_linux_init ();
 
 #endif /* XFCE4_CPUFREQ_LINUX_H */
